// This #include statement was automatically added by the Particle IDE.
#include <Debounce.h>

#include "Serial_LCD_SparkFun.h"


// Create two functions, one for writing on each row
int lcdMsgRow1(String command);
int lcdMsgRow2(String command);

// Set Variable for a new message status
bool newMessage = false;
bool beenHere = false;

// Put an LED and Button on the map
int led1 = 1;
int btn0 = 0;

//Let's prepare to debounce our button
Debounce debounceBtn0 = Debounce();

//Setup our blinking timer
unsigned long previousTime = 0;
int interval = 500;
int ledState = LOW;

// Initialize the LCD library
Serial_LCD_SparkFun lcd = Serial_LCD_SparkFun();


////////////////////////////////////////////////////////////////////////////   SETUP
void setup() {
 // Registering our two cloud functions
 Spark.function("lcdRow1", lcdMsgRow1);
 Spark.function("lcdRow2", lcdMsgRow2);
 
 // Setup the button and led
 pinMode(led1, OUTPUT);
 pinMode(btn0, INPUT_PULLUP);
 //digitalWrite(btn0, HIGH); //set the pullup resistor
 
 debounceBtn0.attach(btn0);
 debounceBtn0.interval(20);
 
 
 // Start with a blank slate
 lcd.clear();
}


////////////////////////////////////////////////////////////////////////////   LOOP
void loop() {
    
    //If a new message has arrived start blinking button
    if (newMessage)
        {
           blinkLED(led1);
        }
    
    //Let's get the button state
    debounceBtn0.update();
    if (debounceBtn0.read()==LOW)
    {
        if (!beenHere)
        {
            digitalWrite(led1, LOW);
            msgReceived();
            newMessage = false;
            beenHere = true;
        }
    
    }else{
        beenHere = false;
    }
}


////////////////////////////////////////////////////////////////////////////   msgReceived
void msgReceived(){
    Spark.publish("Message_Received");
    lcdMsgRow1("Message");
    lcdMsgRow2("Received!");
}


////////////////////////////////////////////////////////////////////////////   blinkLED
void blinkLED(int blinkME){
    
    unsigned long currentTime = millis();
    
    if ( currentTime - previousTime >= interval ){
        previousTime = millis();
        
        if (ledState==HIGH){
            ledState = LOW;
        }else{
            ledState = HIGH;
        }
        
        digitalWrite(blinkME,ledState);
    }
}


////////////////////////////////////////////////////////////////////////////   lcdMsgRow1
int lcdMsgRow1(String command){
    //a new message has arrived!
    newMessage = true;
    
    // Clear the display
    lcd.clear();

    // Write whatever was send to the command
    Serial1.print(command);

    // Return 1 for giggles
    return 1;
}


////////////////////////////////////////////////////////////////////////////   lcdMsgRow2
int lcdMsgRow2(String command){
    //lcd.clear();
    //a new message has arrived!
    //newMessage = false;

    // Ahhh, but this one is a little different!
    // Here we're moving the "cursor" to line 2
    lcd.selectLine(2);
    Serial1.print(command);
    return 1;
}